# Model package

```{eval-rst}
.. automodule:: sec_certs.model
    :no-members:
```

```{tip}
The examples related to this package can be found in the [model notebook](./../notebooks/examples/model.ipynb).
```

## CPEClassifier

```{eval-rst}
.. currentmodule:: sec_certs.model
.. autoclass:: CPEClassifier
    :members:
```

## SARTranformer

```{eval-rst}
.. currentmodule:: sec_certs.model
.. autoclass:: SARTransformer
    :members:
```

## ReferenceFinder

```{eval-rst}
.. currentmodule:: sec_certs.model
.. autoclass:: ReferenceFinder
    :members:
```

## TransitiveVulnerabilityFinder

```{eval-rst}
.. currentmodule:: sec_certs.model
.. autoclass:: TransitiveVulnerabilityFinder
    :members:
```
